@@ -6,6 +6,7 @@
 // Source Licenses. See LICENSE.TXT for details.
 //
 //===----------------------------------------------------------------------===//
+// UNSUPPORTED: c++98, c++03
 
 // <vector>
 
@@ -13,8 +14,9 @@
 //        noexcept(is_nothrow_default_constructible<allocator_type>::value);
 
 // This tests a conforming extension
+// For vector<>, this was added to the standard by N4258,
+//   but vector<bool> was not changed.
 
-// UNSUPPORTED: c++98, c++03
 
 #include <vector>
 #include <cassert>
@@ -31,13 +33,14 @@ struct some_alloc
 
 int main()
 {
+#if defined(_LIBCPP_VERSION)
     {
         typedef std::vector<bool> C;
-        LIBCPP_STATIC_ASSERT(std::is_nothrow_default_constructible<C>::value, "");
+        static_assert(std::is_nothrow_default_constructible<C>::value, "");
     }
     {
         typedef std::vector<bool, test_allocator<bool>> C;
-        LIBCPP_STATIC_ASSERT(std::is_nothrow_default_constructible<C>::value, "");
+        static_assert(std::is_nothrow_default_constructible<C>::value, "");
     }
     {
         typedef std::vector<bool, other_allocator<bool>> C;
@@ -47,4 +50,5 @@ int main()
         typedef std::vector<bool, some_alloc<bool>> C;
         static_assert(!std::is_nothrow_default_constructible<C>::value, "");
     }
+#endif // _LIBCPP_VERSION
 }
