@@ -43,8 +43,8 @@ int main()
     }
     {
     int a[] = {1,2,3,4};
-    std::make_move_iterator(a+4);
-    std::make_move_iterator(a); // test for LWG issue 2061
+    TEST_IGNORE_NODISCARD std::make_move_iterator(a+4);
+    TEST_IGNORE_NODISCARD std::make_move_iterator(a); // test for LWG issue 2061
     }
 
 #if TEST_STD_VER > 14
