@@ -46,7 +46,12 @@ int main()
         }
         catch (const A& a)
         {
+#ifndef _LIBCPP_ABI_MICROSOFT
             assert(A::constructed == 1);
+#else
+            // On Windows the exception_ptr copies the exception
+            assert(A::constructed == 2);
+#endif
             assert(p != nullptr);
             p = nullptr;
             assert(p == nullptr);
@@ -55,4 +60,5 @@ int main()
         }
         assert(A::constructed == 0);
     }
+    assert(A::constructed == 0);
 }
