@@ -7,8 +7,9 @@
 //
 //===----------------------------------------------------------------------===//
 //
-// XFAIL: with_system_cxx_lib=x86_64-apple-darwin11
-// XFAIL: with_system_cxx_lib=x86_64-apple-darwin12
+// PR14919 was fixed in r172447, out_of_range wasn't thrown before.
+// XFAIL: with_system_cxx_lib=macosx10.7
+// XFAIL: with_system_cxx_lib=macosx10.8
 
 // <string>
 
@@ -18,6 +19,7 @@
 #include <string>
 #include <cmath>
 #include <cassert>
+#include <stdexcept>
 
 #include "test_macros.h"
 
