@@ -7,13 +7,17 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef __COUNTING_PREDICATES_H
-#define __COUNTING_PREDICATES_H
+#ifndef TEST_SUPPORT_COUNTING_PREDICATES_H
+#define TEST_SUPPORT_COUNTING_PREDICATES_H
 
+#include <cstddef>
 
 template <typename Predicate, typename Arg>
-struct unary_counting_predicate : public std::unary_function<Arg, bool>  {
+struct unary_counting_predicate {
 public:
+    typedef Arg argument_type;
+    typedef bool result_type;
+
     unary_counting_predicate(Predicate p) : p_(p), count_(0) {}
     ~unary_counting_predicate() {}
 
@@ -24,12 +28,15 @@ public:
 private:
     Predicate p_;
     mutable size_t count_;
-    };
+};
 
 
 template <typename Predicate, typename Arg1, typename Arg2=Arg1>
-struct binary_counting_predicate : public std::binary_function<Arg1, Arg2, bool> {
+struct binary_counting_predicate {
 public:
+    typedef Arg1 first_argument_type;
+    typedef Arg2 second_argument_type;
+    typedef bool result_type;
 
     binary_counting_predicate ( Predicate p ) : p_(p), count_(0) {}
     ~binary_counting_predicate() {}
@@ -41,6 +48,6 @@ public:
 private:
     Predicate p_;
     mutable size_t count_;
-    };
+};
 
-#endif // __COUNTING_PREDICATES_H
+#endif // TEST_SUPPORT_COUNTING_PREDICATES_H
